<?php
/**
 * Clipsan user plugin class
 * @author Clipsan
 */
class clipsan_access {
	
	/**
	 *
	 * @var string
	 */
	protected static $instance;
	
	/**
	 * Default constructor
	 */
	protected function __construct() {
		add_action ( 'wp', array (
				$this,
				'check_single' 
		) );
		add_action ( 'pre_get_posts', array (
				$this,
				'pre_get_posts' 
		) );
		add_action ( 'posts_where', array (
				$this,
				'posts_where' 
		) );
		add_filter ( 'wp_nav_menu_objects', array (
				$this,
				'wp_nav_menu_objects' 
		) );
	}
	
	/**
	 * Get instance
	 *
	 * @return clipsan_access
	 */
	public static function getInstance() {
		if (! isset ( self::$instance )) {
			self::$instance = new clipsan_access ();
		}
		
		return self::$instance;
	}
	
	function check_single() {
		global $post, $wp_query;
		if (is_user_logged_in () && (is_singular ( 'post' ) || is_page ())) {
			if (! $this->check_post ( $post->ID )) {
				$wp_query->set_404 ();
				status_header ( 404 );
			}
		}
	}
	
	protected function check_post($postId) {
		$enabled = true;
		if (current_user_can ( 'list_users' ))
		{
			return true;
		}
		$data = get_post_meta ( $postId, 'clipsan_access_funnelstage', true );
		if ($data) {
			list ( $funnel, $stage ) = explode ( ':', $data );
			$userstage = $this->getUserStage ( $funnel );
			$stages = $this->getFunnelStages ( $funnel );
			$enabled = false;
			foreach ( $stages as $tmpstage ) {
				if ($stage == $tmpstage) {
					$enabled = true;
				}
				if ($userstage == $tmpstage) {
					break;
				}
			}
		}
		return $enabled;
	}
	
	protected function getUserStage($funnelId) {
		$userstage = get_user_meta ( get_current_user_id (), 'clipsan_access_userinfunnel_' . $funnelId, true );
		if (! $userstage) {
			$user = wp_get_current_user ();
			$stage = $this->readLeadStage ( $funnelId, $user->user_email );
			add_user_meta ( get_current_user_id (), 'clipsan_access_userinfunnel_' . $funnelId, serialize ( array (
					$stage,
					time () 
			) ) );
			$modified = time ();
		} else {
			list ( $stage, $modified ) = unserialize ( $userstage );
		}
		if ($modified < time () - 5 * 60) {
			$user = wp_get_current_user ();
			$stage = $this->readLeadStage ( $funnelId, $user->user_email );
			update_user_meta ( get_current_user_id (), 'clipsan_access_userinfunnel_' . $funnelId, serialize ( array (
					$stage,
					time () 
			) ) );
		}
		return $stage;
	}
	
	protected function readLeadStage($funnelId, $email) {
		$clipsan_securekey = get_option ( 'clipsan_securekey' );
		$url = 'https://clipsan.com/api/lead/view/key/' . $clipsan_securekey . '/email/' . $email;
		$stage = false;
		$data = file_get_contents ( $url );
		$result = json_decode ( $data );
		if ($result->result == 'ok') {
			$lead = $result->lead;
			if (isset ( $lead->funnels ) && isset ( $lead->funnels->$funnelId )) {
				$stage = $lead->funnels->$funnelId;
			}
		}
		return $stage;
	}
	
	protected function getFunnelStages($funnelId) {
		$funneldata = get_option ( 'clipsan_funnel_' . $funnelId );
		if (! $funneldata) {
			$funnel = $this->readFunnelStages ( $funnelId );
			add_option ( 'clipsan_funnel_' . $funnelId, serialize ( array (
					$funnel,
					time () 
			) ) );
			$modified = time ();
		} else {
			list ( $funnel, $modified ) = unserialize ( $funneldata );
		}
		if ($modified < time () - 5 * 60) {
			$funnel = $this->readFunnelStages ( $funnelId );
			update_option ( 'clipsan_funnel_' . $funnelId, serialize ( array (
					$funnel,
					time () 
			) ) );
		}
		return $funnel;
	}
	
	protected function readFunnelStages($funnelId) {
		$clipsan_securekey = get_option ( 'clipsan_securekey' );
		$url = 'https://clipsan.com/api/funnel/view/key/' . $clipsan_securekey . '/id/' . $funnelId;
		$data = file_get_contents ( $url );
		$result = json_decode ( $data );
		$stages = array ();
		if ($result->result == 'ok') {
			foreach ( $result->funnel->stages as $stageId => $stage ) {
				$stages [] = $stageId;
			}
		}
		return $stages;
	}
	
	function pre_get_posts($query) {
		if (is_admin ()) {
			return;
		}
		if (isset ( $query->query_vars ['post_type'] ) && $query->query_vars ['post_type'] == 'post') {
		}
	}
	
	function posts_where($where) {
		global $wpdb;
		
		if (is_admin ()) {
			return $where;
		}
		
		$where .= "AND (SELECT COUNT(*) FROM {$wpdb->postmeta} AS timeoutmeta WHERE {$wpdb->posts}.ID = timeoutmeta.post_id AND timeoutmeta.meta_key = 'ffuk_post_timeout' AND CAST(timeoutmeta.meta_value AS UNSIGNED) < " . time () . ") = 0";
		
		return $where;
	}
	
	public function wp_nav_menu_objects($sorted_menu_items, $args = null) {
		$result = array ();
		foreach ( $sorted_menu_items as $post ) {
			/* @var $post WP_Post */
			if ($this->check_post ( $post->object_id )) {
				$result [] = $post;
			}
		}
		return $result;
	}
}

