<?php
/**
 * Clipsan user plugin class
 * @author Clipsan
 */
class clipsan_user {
	
	/**
	 *
	 * @var string
	 */
	protected static $instance;
	
	/**
	 * Default constructor
	 */
	protected function __construct($file) {
		register_activation_hook ( $file, array (
				$this,
				'activation' 
		) );
		register_deactivation_hook ( $file, array (
				$this,
				'deactivation' 
		) );
		
		add_action ( 'admin_menu', array (
				$this,
				'adminMenu' 
		) );
	}
	
	/**
	 * Get instance
	 *
	 * @return clipsan_user
	 */
	public static function getInstance($file = '') {
		if (! isset ( self::$instance )) {
			self::$instance = new clipsan_user ($file);
		}
		
		return self::$instance;
	}
	
	function activation() {
		add_option ( 'clipsan_securekey' );
		
		$table_name = $this->getLogTableName ();
		
		$charset_collate = '';
		
		if (! empty ( $wpdb->charset ))
			$charset_collate = "DEFAULT CHARACTER SET $wpdb->charset";
		if (! empty ( $wpdb->collate ))
			$charset_collate .= " COLLATE $wpdb->collate";
		
		$sql = "CREATE TABLE $table_name (
			id int(11) NOT NULL AUTO_INCREMENT,
			request TEXT DEFAULT NULL,
			response TEXT DEFAULT NULL,
			ip VARCHAR(20) DEFAULT NULL,
			user_id int(11) DEFAULT NULL,
			added datetime NOT NULL,
			PRIMARY KEY (`id`)
		) ENGINE=MyISAM $charset_collate";
		
		require_once (ABSPATH . 'wp-admin/includes/upgrade.php');
		dbDelta ( $sql );
	}
	
	function deactivation() {
		global $wpdb;
		
		delete_option ( 'clipsan_securekey' );
		
		$sql = "DROP TABLE IF EXISTS " . $this->getLogTableName () . ";";
		$wpdb->query ( $sql );
	}
	
	function adminMenu() {
		add_options_page ( __('Clipsan uživatelé', 'clipsan'), __('Clipsan uživatelé', 'clipsan'), 'manage_options', 'clipsan-user', array (
				$this,
				'admin' 
		) );
	}
	
	function admin() {
		global $wpdb, $member_module;
		
		if (isset ( $_POST ['clipsan_submit'] )) {
			$clipsan_securekey = stripslashes ( $_POST ['clipsan_securekey'] );
			update_option ( 'clipsan_securekey', $clipsan_securekey );
		}
		$clipsan_securekey = get_option ( 'clipsan_securekey' );
		
		if (defined('MEMBER_VERSION') && isset($member_module))
		{
			$script = 'mioweb.php';
			$ismio = true;
		}
		else
		{
			$script = 'remote.php';
			$ismio = false;
		}
		?>
<div class="wrap">
	<h2><?php _e('Clipsan uživatelé', 'clipsan'); ?></h2>
	<form name="form_mt" method="post" action="">
		<table class="form-table">
			<tr valign="top">
				<th scope="row"><label for="clipsan_securekey"><?php _e('Chráněný klíč', 'clipsan') ?></label></th>
				<td><input name="clipsan_securekey" type="text"
					value="<?php echo $clipsan_securekey; ?>" id="clipsan_securekey"
					class="regular-text" placeholder="<?php _e('Zadejte chráněný klíč', 'clipsan') ?>"
					required="required" /><br /><span class="description"><?php _e('Chráněný klíč získáte <a href="https://clipsan.com/cs/clipsan/securekey">zde</a>.', 'clipsan') ?></span></td>
			</tr>
		</table>
		<p class="submit">
			<input type="submit" name="clipsan_submit" id="clipsan_submit"
				class="button-primary" value="<?php _e('Uložit změny', 'clipsan') ?>" />
		</p>
	</form>
	<h2><?php echo _e('Adresa volání', 'clipsan'); ?></h2>
		<table class="form-table">
			<?php if ($ismio): $rows = '';?>
			<tr valign="top">
				<th scope="row"><label for="clipsan_member"><?php _e('Členská sekce', 'clipsan') ?></label></th>
				<td><select id="clipsan_member" name="clipsan_member" class="generator">
					<?php $meta=get_option('member_basic'); ?>
					<?php foreach ($meta['members'] as $id => $memberarea): $postfix= isset($postfix) ? $postfix : '?add_new_member='.$id ?>
						<option value="<?php echo $id ?>"><?php echo $memberarea['name'] ?></option>
						<?php if(isset($memberarea['levels'])) {
								$levels = '';
								foreach($memberarea['levels'] as $lid => $level) {
									$levels .= '<option value="'.$lid.'">'.$level['name'].'</option>';
								}
							$rows .= '</tr><tr id="clipsan_member_tr_'.$id.'" class="levelrow"><th><label for="clipsan_member_'.$id.'">'.__('Členská úroveň', 'clipsan').'</label></th><td><select id="clipsan_member_'.$id.'" name="clipsan_member" class="generator memberlevel">'.$levels.'</select></td>'; 
						}
						?>
					<?php endforeach ?>
				</select></td>
				<?php echo $rows ?>
			<?php else: ?>
			<tr valign="top">
				<th scope="row"><label for="clipsan_role"><?php _e('Role uživatele', 'clipsan') ?></label></th>
				<td><select id="clipsan_role" name="clipsan_role" class="generator">
					<option value=""><?php _e('Výchozí role', 'clipsan') ?></option>
					<?php foreach (get_editable_roles() as $role_name => $role_info): ?>
						<option value="<?php echo $role_name ?>"><?php echo print_r($role_info['name'], true)?></option>
					<?php endforeach ?>
				</select></td>
			<?php endif ?>
			</tr><tr valign="top">
				<th scope="row"><label for="clipsan_reg"><?php _e('Datum registrace', 'clipsan') ?></label></th>
				<td><input name="clipsan_reg" type="date"  class="generator"
					value="" id="clipsan_reg"
					class="" placeholder="<?php _e('Zadejte datum registrace', 'clipsan') ?>"
					 /><input name="clipsan_reg_time" type="time"
					value="" id="clipsan_reg_time"
					class="" placeholder="<?php _e('Zadejte čas registrace', 'clipsan') ?>"
					 /> <?php _e('Formát je Y-m-d H:i tj. 2015-12-01 11:55', 'clipsan')?></td>
			</tr><tr valign="top">
				<th scope="row"><label for="clipsan_notify"><?php _e('Přihlašovací údaje', 'clipsan') ?></label></th>
				<td><label><input name="clipsan_notify" type="checkbox"  class="generator"
					value="1" id="clipsan_notify"
					 /> <?php _e('Nezasílat informace k přihlášení', 'clipsan')?></label></td>
			</tr>
			<?php if (!$ismio): ?>
			<tr valign="top">
				<th scope="row"><label for="clipsan_edit"><?php _e('Chování při editaci', 'clipsan') ?></label></th>
				<td><label><input name="clipsan_edit" type="checkbox"  class="generator"
					value="1" id="clipsan_edit"
					 /> <?php _e('Neměnit heslo, pokud už uživatel existuje', 'clipsan')?></label></td>
			</tr>
			<?php endif ?>
			<?php if (!$ismio): ?>
			<tr valign="top">
				<th scope="row"><label for="clipsan_cap"><?php _e('Custom Capabilities', 'clipsan') ?></label></th>
				<td><input name="clipsan_cap" type="text" class="generator"
					value="" id="clipsan_cap"
					class="regular-text" placeholder="<?php _e('Zadejte capabilities oddělené čárkou', 'clipsan') ?>"
					/><br /><span class="description"><?php _e('Velmi pokročilé nastavení pro OptimizeMember (access_optimizemember_ccap_*), S2Member (access_s2member_ccap_*) apod.', 'clipsan') ?></span></td>
			</tr>
			<?php endif ?>
		</table>
		<script>
		function clipsan_url_generate(){
				var url = '<?php echo site_url('/wp-content/plugins/clipsan-user/'.$script) ?>';
				var first = true;
				if (jQuery('#clipsan_member').val()) {
					var id = jQuery('#clipsan_member').val();
					url += first ? '?' : '&';
					first = false;
					url += 'add_new_member=' + id;
					jQuery('.levelrow').hide();
					jQuery('#clipsan_member_tr_'+id).show();
					if (typeof jQuery('#clipsan_member_'+id).val() != "undefined"){
						url += '&level=' + jQuery('#clipsan_member_'+id).val();
					}
				}
				if (jQuery('#clipsan_role').val()) {
					url += first ? '?' : '&';
					first = false;
					url += 'role=' + jQuery('#clipsan_role').val();
				}
				if (jQuery('#clipsan_cap').val()) {
					url += first ? '?' : '&';
					first = false;
					url += 'cap=' + jQuery('#clipsan_cap').val();
				}
				if (jQuery('#clipsan_reg').val() != '') {
					url += first ? '?' : '&';
					first = false;
					url += 'reg=' + jQuery('#clipsan_reg').val() + " " + jQuery('#clipsan_reg_time').val();
				}
				if (document.getElementById('clipsan_notify') && document.getElementById('clipsan_notify').checked) {
					url += first ? '?' : '&';
					first = false;
					url += 'notify=0';
				}
				if (document.getElementById('clipsan_edit') && document.getElementById('clipsan_edit').checked) {
					url += first ? '?' : '&';
					first = false;
					url += 'edit=0';
				}
				jQuery('#clipsan_url').val(url);
		}
		jQuery('.generator').change(function(e){
			clipsan_url_generate();
		});
		jQuery('#clipsan_cap').keyup(function(e){
			clipsan_url_generate();
		});
		clipsan_url_generate();
		</script>
	<h2><?php echo _e('URL adresa, kterou vložíte do Clipsanu', 'clipsan'); ?></h2>
	<input type="text" id="clipsan_url" class="regular-text" style="width: 100%; padding: 1em; background: orange" value="<?php echo site_url('/wp-content/plugins/clipsan-user/'.$script) ?><?php echo $postfix ?>" readonly="readonly">
	<h2><?php echo _e('Log volání', 'clipsan'); ?></h2>
	<table></table>
	<?php 
	$results = $wpdb->get_results("SELECT request, response, ip, user_id, added FROM ".$this->getLogTableName (). " ORDER BY added DESC LIMIT 20");
	$data = '';
	foreach ($results as $row): 
		$user = get_user_by('id', $row->user_id);
		$data .= '<tr>
		<td>'.nl2br($row->request).'</td>
		<td>'.$row->response.'</td>
		<td>'.$row->ip.'</td>';
		if ($row->user_id){
			$data .= '<td><a href="'.site_url('/wp-admin/user-edit.php?user_id='.$row->user_id).'">'.$user->user_login.'</a> &lt;'.$user->user_email.'&gt;</td>';
		}
		else {
			$data .= '<td>-</td>';
		}
		$data .= '<td>'.mysql2date('j.n.Y. H:i:s', $row->added).'</td>
		</tr>';
	endforeach; 
	if (!$data)
	{
		echo 'Žádné volání zatím neproběhlo nenalezeno.';
	}
	else
	{
		echo '<table class="wp-list-table widefat fixed striped posts">
			<thead><tr>
			<th>Volání</th>
			<th>Odpověď</th>
			<th>IP</th>
			<th>Uživatel</th>
			<th>Přidáno</th>
		</tr></thead>
			<tbody>'.$data.'</tbody>
		</table>';
	}
	?>
</div>
<?php
	}
	
	public function getLogTableName() {
		global $wpdb;
		return $wpdb->prefix . "clipsan_user_log";
	}
}

