<?php
require_once '../../../wp-load.php';

// start logging
$logId = false;
if (class_exists('clipsan_user', false))
{
	$wpdb->insert(clipsan_user::getInstance()->getLogTableName(), array(
		'request' => $_SERVER['REQUEST_URI'] . "\n" . print_r($_REQUEST, true), 
		'ip' => $_SERVER['REMOTE_ADDR'], 
		'added' => date('Y-m-d H:i:s')));
	$logId = $wpdb->insert_id;
}

// finish logging and flush response
function finish($result, $logId, WP_User $user = null)
{
	global $wpdb;
	if ($logId)
	{
		$wpdb->update(clipsan_user::getInstance()->getLogTableName(), array(
			'response' => $result, 
			'user_id' => $user ? $user->ID : null), array(
			'id' => $logId));
	}
	die("$result");
}

// process capabilities
function setup_capabilities(WP_User $user)
{
	if (isset($_REQUEST['cap']) && $_REQUEST['cap'])
	{
		if (!is_array($_REQUEST['cap']) && strpos($_REQUEST['cap'], ',') !== false)
		{
			$capabilities = split(',', $_REQUEST['cap']);
		}
		else
		{
			$capabilities = $_REQUEST['cap'];
		}
		if (is_array($capabilities))
		{
			foreach ($capabilities as $cap)
			{
				$user->add_cap(trim($cap));
			}
		}
		else
		{
			$user->add_cap(trim($capabilities));
		}
	}
}

// check security
$securekey = get_option('clipsan_securekey');
$security = sha1($_REQUEST['login'] . $_REQUEST['email'] . $_REQUEST['pass'] . $_REQUEST['t'] . $securekey);
if ($security != $_REQUEST['hash'])
{
	finish('invalid security', $logId);
}

// prepare data
$userdata = array(
	'user_login' => $_REQUEST['login'], 
	'user_email' => $_REQUEST['email'], 
	'first_name' => $_REQUEST['firstname'], 
	'last_name' => $_REQUEST['surname'], 
	'role' => isset($_REQUEST['role']) && $_REQUEST['role'] ? $_REQUEST['role'] : 'subscriber', 
	'user_pass' => $_REQUEST['pass']);

// check email duplicity
// if found return previous user
$user = get_user_by('email', $_REQUEST['email']);
if ($user)
{
	// change password when not enforcing edit
	if (!isset($_REQUEST['edit']) || $_REQUEST['edit'])
	{
		wp_set_password($_REQUEST['pass'], $user->ID);
	}
	// change role if given
	if (isset($_REQUEST['role']) && $_REQUEST['role'])
	{
		$user = new WP_User($user->ID);
		$user->set_role($_REQUEST['role']);
	}
	setup_capabilities($user);
	finish($user->ID . ':' . $user->user_login, $logId, $user);
}

// check login duplicity
// if found create a new login name
$user = get_user_by('login', $_REQUEST['login']);
if ($user)
{
	$i = 1;
	do
	{
		$userdata['user_login'] = $_REQUEST['login'] . sprintf('%02d', $i);
		$user = get_user_by('login', $userdata['user_login']);
		$i++;
	}
	while ($user);
}

// preform insert
if (isset($_REQUEST['reg']) && preg_match('/\d{4}-\d{2}-\d{2} \d{2}:\d{2}/', $_REQUEST['reg']))
{
	$userdata['user_registered'] = $_REQUEST['reg'] . ':00';
}
$user_id = wp_insert_user($userdata);

// check response
if (is_wp_error($user_id))
{
	finish($user_id->get_error_message(), $logId);
}
else 
	if ($user_id)
	{
		$user = new WP_User($user_id);
		
		// notify user
		if (!isset($_REQUEST['notify']) || $_REQUEST['notify'])
		{
			wp_new_user_notification($user_id, $userdata['user_pass']);
		}
		
		setup_capabilities($user);
		finish($user->ID . ':' . $user->user_login, $logId, $user);
	}